'' TopFile derived from Mike Green's FemtoBasic v2.002, with Tomas Rokicki's FAT16 SD Support 
''
''   File...... SD_SpinLoader_wTVDisplay.spin
''   Purpose... Loads a SPIN binary from the SD card, and runs SPIN application
'' 
''   Author.... Mike Cook
''   E-mail.... mike-cook@tx.rr.com 
''   Started... March 14, 2007
''   Updated... 
''   Compiler.. Parallax Propeller Tool v1.05.4
''   Platform.. Propeller Proto Board, Stock#: 32212    
''
''   Links..... SD Support:     http://tomas.rokicki.com/fat16work/
''                              http://forums.parallax.com/forums/default.aspx?f=25&m=162235
''              FemtoBasic:     http://forums.parallax.com/forums/default.aspx?f=25&m=173975
''              TV_Text   :     Parallax; http://www.parallax.com/dl/sw/propeller/Setup-Propeller-Tool-v1.05.2.exe
''              Propeller Tool: http://forums.parallax.com/forums/default.aspx?f=25&m=172361
''                              v1.05.4 - http://forums.parallax.com/forums/attach.aspx?a=12406
''
''   Notes..... 1. To create a SPIN Binary:
''                   a. Make sure your application's top file is selected in the Propeller Tool's tabbed display
''                   b. Press F8 in the Propeller Tool
''                   c. Click on the "Save Binary File" button
''
''              2. Prepare SD card:
''                   a. Using your PC's OS; example: Windows XP; format a SD card to have a FAT 16 file structure
''                   b. Copy the file, created in step 1 item c, to the SD card
''                   c. Rename the file to the DOS 8x3 file name format; example: xxxxxxxx.xxx
''
''              3. Load the Propeller platform:
''                   a. Install the SD card in the Propeller platform 
''                   b. Change the file name in this file to your file's name, see DAT section, FileName
''                   c. Press F11 to compile and load EEPROM
''
''   History... March 14, 2007 - Created this Top File to load a SPIN application from a SD card. Tested and added
''                               documentation. 
''
''
obj
   fsrw  : "fsrwFemto"                                     ' FAT File System Read/Write
   dsp   : "tv_text"                                       ' TV Text Driver  

   
con
   _clkmode  = xtal1 + pll16x                              ' Run at 80 Mhz
   _xinfreq  = 5_000_000                                   ' 5 MHz crystal
   
   spiDO     = 0                                           ' SD card installed on Pins 0..3
   spiClk    = 1
   spiDI     = 2
   spiCS     = 3
   
   display   = 12                                          ' NTSC TV display installed on Pins 12..15

      
var
   long ioControl[2]                                       ' Needed for fsrwFemto


pub main
   dsp.start(display)                                      ' Start TV display Driver
   fsrw.start(@ioControl)                                  ' Start I2C/SPI driver
   if \fsrw.mount(spiDO,spiClk,spiDI,spiCS) < 0            ' Attempt to mount SD card
     abort dsp.str(@SdCardErr)                             '   if problem with SD card display card error
   if \fsrw.popen(@FileName,"r")                           ' Attempt to open application file
     abort dsp.str(@SdFileErr)                             '   if application is not present then display file error
   fsrw.bootSDCard                                         ' All is good, boot application


dat
   SdCardErr  byte  "Can't Mount SD card", 0
   SdFileErr  byte  "Can't open file", 0

   FileName   byte  "test.bin", 0                          ' File name of your Propeller application saved to SD card

    